<template>
  <a-spin :spinning='confirmLoading'>
    <j-form-container :disabled='formDisabled'>
      <a-form-model ref='form' :model='model' :rules='validatorRules' slot='detail'>
        <a-row>
          <!--          <a-col :span="24">
                      <a-form-model-item label="反馈类型" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="type">
                        <j-dict-select-tag type="list" v-model="model.type" dictCode="" placeholder="请选择反馈类型" />
                      </a-form-model-item>
                    </a-col>-->
          <a-col :span='24'>
            <a-form-model-item label='反馈&建议' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='description'>
              <a-textarea v-model='model.description' rows='4' :placeholder='placehold' />
            </a-form-model-item>
          </a-col>

          <a-col :span='24'>
            <a-form-model-item label='反馈&截图' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='img'>
              <j-image-upload isMultiple bizPath='fed' v-model='model.img'></j-image-upload>
            </a-form-model-item>
          </a-col>

        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>

import { httpAction, getAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'

export default {
  name: 'SysFeedbackForm',
  components: {},
  props: {
    //表单禁用
    disabled: {
      type: Boolean,
      default: false,
      required: false
    }
  },
  data() {
    return {
      placehold: '为了不断改进和提升系统的功能和用户体验，我们非常重视您的反馈和建议，我们会对每一条反馈进行认真阅读并采取适当的行动。您的声音对于我们来说非常重要，它将直接影响我们未来的改进计划和用户体验。 '
      ,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      validatorRules: {
        description: [
          { required: true, message: '请输入描述!' }
        ],
        type: [
          { required: true, message: '请输入反馈类型!' }
        ]
      },
      url: {
        add: '/sys/fed/add',
        edit: '/sys/fed/edit',
        queryById: '/sys/fed/queryById'
      }
    }
  },
  computed: {
    formDisabled() {
      return this.disabled
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model))
  },
  methods: {
    add() {
      this.edit(this.modelDefault)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    submitForm() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        }

      })
    }
  }
}
</script>